@@ -230,12 +230,17 @@ def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
     """Return the HTML representation of the given dataframe as an interactive datatable"""
     # Default options
     for option in dir(opt):
-        if option not in kwargs and not option.startswith("__"):
+        if (
+            option not in kwargs
+            and not option.startswith("__")
+            and option != "read_package_file"
+        ):
             kwargs[option] = getattr(opt, option)
 
     # These options are used here, not in DataTable
     classes = kwargs.pop("classes")
     style = kwargs.pop("style")
+    css = kwargs.pop("css")
     tags = kwargs.pop("tags")
 
     showIndex = kwargs.pop("showIndex")
@@ -311,9 +316,7 @@ def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
     output = replace_value(
         output,
         "<style></style>",
-        f"""<style>
-{read_package_file("html/style.css")}
-</style>""",
+        f"""<style>{css}</style>""",
     )
 
     if column_filters:
